from django import forms
import imghdr
from django.http import JsonResponse
import re, phonenumbers
from django.core.validators import URLValidator
from phonenumbers import geocoder, carrier
from .functions import caption_optimizer
from datetime import date, timedelta
from geolocation.models import City, Country
from django.forms import BaseFormSet
from django.core.exceptions import ValidationError
from django.utils.translation import gettext_lazy as _
from crispy_forms.helper import FormHelper
from accounts.models import UserBase
from .models import (
        Newsletter, BillingRecipt, ItemProducts, ItemServices,ItemDiscount, 
        Templates, Content, Inventory, Modules, TemplateSections, StelaColors,
        Variants, Sizes, Gallery, Bulletpoints, VariantsImage, Wallet, DynamicBullets, 
        DataEmail, Category, SitePolicy, LegalProvision, Support, SupportResponse, ChatSupport, 
        FacebookPostPage, FacebookPageComments, FacebookPageCommentsReply,FacebookPageEvent, 
        FacebookPageLikes, FacebookPageMessages, FAQ, Contact, Comments, FacebookPageShares, 
        FacebookPostMedia, IGPost, ContactResponse, IGMediaContent, Company, SocialLinks, ImageGallery,
        SetFaq, Reviews, ProStelaExpert, LiteraryWork, Resource, BillFile
)
import re
#Support
class SupportForm(forms.ModelForm):
    class Meta:
        model = Support
        fields = ['option','message','terms','image']

        def __init__(self, *args, **kwargs):
            super().__init__(*args, **kwargs)
            self.fields['image'].widget.attrs.update(
                    {'class': 'form-control'})
            
class ReadOnlySupportForm(forms.ModelForm):
    class Meta:
        model = Support
        fields = ['option','message','terms', 'status']
    
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields["option"].disabled = True
        self.fields["message"].disabled = True
        self.fields["terms"].disabled = True

class ReadOnlySupportFormCostumer(forms.ModelForm):
    class Meta:
        model = Support
        fields = ['option','message','terms']
    
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields["option"].disabled = True
        self.fields["message"].disabled = True
        self.fields["terms"].disabled = True

#Billing 
class BillingForm(forms.ModelForm):
    class Meta: 
        model = BillingRecipt
        fields = ['report', 'option']
    
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

        self.fields["report"].required = False

class BillingFormSuscription(forms.ModelForm):
    class Meta: 
        model = BillingRecipt
        fields = ['report']
    
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

        self.fields["report"].required = False

class BillingChargeFormPOS(forms.ModelForm):
    class Meta:
        model = ItemProducts
        fields = ['field','qty']
      
    def __init__(self, *args, **kwargs):
        self.request = kwargs.pop('request', None)
        super().__init__(*args, **kwargs)
        self.fields['field'].widget.attrs.update(
            {'class': 'form-control col-lg-8 mx-3 mb-4', 'placeholder': 'Field'})
        self.fields['qty'].widget.attrs.update(
            {'class': 'form-control col-lg-2 mx-3 mb-4', 'placeholder': 'qty'})
        self.fields['field'].label = False
        self.fields['qty'].label = False
        self.fields['field'].queryset = Variants.objects.filter(product__lang=self.request.LANGUAGE_CODE)

class BillingChargeFormDynamic(forms.ModelForm):
    class Meta:
        model = ItemServices
        fields = ['field','qty']
      
    def __init__(self, *args, **kwargs):
        self.request = kwargs.pop('request', None)
        super().__init__(*args, **kwargs)
        self.fields['field'].widget.attrs.update(
            {'class': 'form-control col-lg-8 mx-3 mb-4', 'placeholder': 'Field'})
        self.fields['qty'].widget.attrs.update(
            {'class': 'form-control col-lg-2 mx-3 mb-4', 'placeholder': 'qty'})
        self.fields['field'].label = False
        self.fields['qty'].label = False
        self.fields['field'].required = True
        self.fields['qty'].required = True
        self.fields['field'].queryset = Modules.objects.filter(parent__owner=self.request.user, parent__yearly=False, parent__type="Service", parent__lang=self.request.LANGUAGE_CODE).order_by('parent').exclude(price=0)   

class BillingDiscountForm(forms.ModelForm):
    class Meta: 
        model = ItemDiscount
        fields = ['field','amount']
    
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

        self.fields['field'].widget.attrs.update(
            {'class': 'form-control col-lg-8 mx-3 mb-4', 'placeholder': 'Field'})
        self.fields['amount'].widget.attrs.update(
            {'class': 'form-control col-lg-2 mx-3 mb-4', 'placeholder': 'amount'})
        self.fields['field'].label = False
        self.fields['amount'].label = False
        self.fields['field'].required = True
        self.fields['amount'].required = True

#invoiceCustom
class RequiredFormSet(BaseFormSet):
    def __init__(self, *args, **kwargs):
       super(RequiredFormSet, self).__init__(*args, **kwargs)
       for form in self.forms:
         form.empty_permitted = False

#developerLoad
class categForm(forms.ModelForm):

    class Meta: 
        model = Category
        exclude = ('slug', 'owner',)
        fields = '__all__'

class TempSecForm(forms.ModelForm):

    class Meta: 
        model = TemplateSections
        fields = ['section']

class StylesForm(forms.ModelForm):

    class Meta: 
        model = Content
        fields = ['parent', 'title', 'media']
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['image'].widget.attrs.update(
                {'class': 'form-control'})
        
class ColorsForm(forms.ModelForm):

    class Meta: 
        model = StelaColors
        exclude = ('owner',)
        fields = '__all__'

#inventory Product
class ProductForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields["image"].required = True
        self.fields['image'].widget.attrs.update(
                    {'class': 'form-control'})
    class Meta:
        model = Inventory
        exclude = ('slug','owner','type','price','qty', 'sku', 'lang', 'id')
        fields = '__all__'

class ServiceForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields["image"].required = True
        self.fields['image'].widget.attrs.update(
                    {'class': 'form-control'})
    class Meta:
        model = Inventory
        exclude = ('slug','owner','type', 'sku', 'category', 'lang', 'id')
        fields = '__all__'

class ModulesForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['image'].widget.attrs.update(
                {'class': 'form-control'})
    class Meta:
        model = Modules
        exclude = ('parent',)
        fields = '__all__'

class VariantForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields["product"].queryset = Inventory.objects.filter(type="Product").order_by('title')
        self.fields['image'].widget.attrs.update(
                {'class': 'form-control'})
    class Meta:
        model = Variants
        fields = '__all__'
        exclude = ('id',)
    
class SizeForm(forms.ModelForm):

    class Meta:
        model = Sizes
        exclude = ('product','id')
        fields = '__all__'

class GalleryForm(forms.ModelForm):

    class Meta:
        model = Gallery
        exclude = ('catalogue', 'id')
        fields = '__all__'

class BulletForm(forms.ModelForm):

    class Meta:
        model = Bulletpoints
        exclude = ('product', 'id')
        fields = '__all__'

class VariantImageForm(forms.ModelForm):

    class Meta:
        model = VariantsImage
        fields = '__all__'
        exclude = ('id',)

class TemplateForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['image'].widget.attrs.update(
                        {'class': 'form-control'})
    class Meta:
        model = Templates
        exclude = ('slug', 'id',)
        fields = '__all__'
    
#ContentStela (AboutSection, SliderSection, BoxSection, PortfolioSection, MediaSection, MisionSection, LegalSection, FooterSections, LinkSections)
class StelaAboutForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['media'].widget.attrs.update(
                {'class': 'form-control'})
    class Meta:
        model = Content
        fields = ['title', 'content', 'media', 'status']

class AppstelaForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['media'].widget.attrs.update(
                {'class': 'form-control'})
    class Meta:
        model = Content
        fields = ['appstela','subtitle','content','media','url', 'status'] 

class PathForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    class Meta:
        model = Content
        fields = ['path', 'content', 'status']

class MediaForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['media'].widget.attrs.update(
                {'class': 'form-control'})
    class Meta:
        model = Content
        fields = ['media', 'url', 'status']

class FooterContentForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['content'].label = False

    class Meta:
        model = Content
        fields = ['content', 'status', 'status']

class ContactForm(forms.ModelForm):
    class Meta:
        model = Contact
        fields = '__all__'

class PolicyForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

        for field in self.fields.values():
            field.widget.attrs['placeholder'] = field.label
            field.label = False

    class Meta:
        model = SitePolicy
        fields = ['title','section','status']

class LegalProvitionForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

        for field in self.fields.values():
            field.widget.attrs['placeholder'] = field.label
            field.label = False

    class Meta:
        model = LegalProvision
        fields = ['clause', 'clause_content']

#SiteContent
class TextContentForm(forms.ModelForm):
    class Meta:
        model = Content
        fields = ['title','subtitle',]
        
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
    
        for field in self.fields.values():
            field.widget.attrs['placeholder'] = field.label
            field.label = False
           
    def clean_title(self):
        title = self.cleaned_data["title"]

        if not title:
            raise forms.ValidationError(_("The title is required."))
        
        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', title):
            raise forms.ValidationError(_("The title contains unauthorized characters."))

        return title

    def clean_subtitle(self):
        subtitle = self.cleaned_data["subtitle"]

        if not subtitle:
            raise forms.ValidationError(_("The subtitle is required."))

        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', subtitle):
            raise forms.ValidationError(_("The subtitle contains unauthorized characters."))

        return subtitle

    def clean_content(self):
        content = self.cleaned_data["content"]

        if not content:
            raise forms.ValidationError(_("The content is required."))

        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', content):
            raise forms.ValidationError(_("The content contains unauthorized characters."))

        return content

class SimpleContentForm(forms.ModelForm):

    class Meta:
        model = Content
        fields = ['title','subtitle','media',]
        
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
    
        for field in self.fields.values():
            field.widget.attrs['placeholder'] = field.label
            field.label = False
            self.fields['media'].widget.attrs.update(
                {'class': 'form-control'})
            
    def clean_title(self):
        title = self.cleaned_data["title"]

        if not title:
            raise forms.ValidationError(_("The title is required."))
        
        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', title):
            raise forms.ValidationError(_("The title contains unauthorized characters."))

        return title

    def clean_subtitle(self):
        subtitle = self.cleaned_data["subtitle"]

        if not subtitle:
            raise forms.ValidationError(_("The subtitle is required."))

        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', subtitle):
            raise forms.ValidationError(_("The subtitle contains unauthorized characters."))

        return subtitle

    def clean_media(self):
        image = self.cleaned_data["media"]

        if not image:
            raise forms.ValidationError(_("The image container cannot be empty."))

        image_format = imghdr.what(image)
        if image_format not in ['jpeg', 'png']:
            raise forms.ValidationError(_("The image format is not valid. Only JPEG and PNG files are allowed."))

        return image
    
class ContentForm(forms.ModelForm):

    class Meta:
        model = Content
        fields = ['title','subtitle','media', 'content',]
        
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
    
        for field in self.fields.values():
            field.widget.attrs['placeholder'] = field.label
            field.label = False
            self.fields['media'].widget.attrs.update(
                {'class': 'form-control'})
            
    def clean_title(self):
        title = self.cleaned_data["title"]

        if not title:
            raise forms.ValidationError(_("The title is required."))
        
        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', title):
            raise forms.ValidationError(_("The title contains unauthorized characters."))

        return title

    def clean_subtitle(self):
        subtitle = self.cleaned_data["subtitle"]

        if not subtitle:
            raise forms.ValidationError(_("The subtitle is required."))

        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', subtitle):
            raise forms.ValidationError(_("The subtitle contains unauthorized characters."))

        return subtitle

    def clean_content(self):
        content = self.cleaned_data["content"]
        clean_content=caption_optimizer(content)
        
        if not content:
            raise forms.ValidationError(_("The content is required."))

        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', clean_content):
            raise forms.ValidationError(_("The content contains unauthorized characters."))

        return content
    
    def clean_media(self):
        image = self.cleaned_data["media"]

        if not image:
            raise forms.ValidationError(_("The image container cannot be empty."))

        image_format = imghdr.what(image)
        if image_format not in ['jpeg', 'png']:
            raise forms.ValidationError(_("The image format is not valid. Only JPEG and PNG files are allowed."))

        return image

class AboutContentForm(forms.ModelForm):

    class Meta:
        model = Content
        fields = ['about','title','media', 'content',]
        
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
    
        for field in self.fields.values():
            field.widget.attrs['placeholder'] = field.label
            field.label = False
            self.fields['media'].widget.attrs.update(
                {'class': 'form-control'})
            
    def clean_title(self):
        title = self.cleaned_data["title"]

        if not title:
            raise forms.ValidationError(_("The title is required."))
        
        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', title):
            raise forms.ValidationError(_("The title contains unauthorized characters."))

        return title

    def clean_content(self):
        content = self.cleaned_data["content"]
        clean_content=caption_optimizer(content)
        
        if not content:
            raise forms.ValidationError(_("The content is required."))

        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', clean_content):
            raise forms.ValidationError(_("The content contains unauthorized characters."))

        return content
    
    def clean_media(self):
        image = self.cleaned_data["media"]

        if not image:
            raise forms.ValidationError(_("The image container cannot be empty."))

        image_format = imghdr.what(image)
        if image_format not in ['jpeg', 'png']:
            raise forms.ValidationError(_("The image format is not valid. Only JPEG and PNG files are allowed."))

        return image

class ContentDynamicForm(forms.ModelForm):

    class Meta:
        model = Content
        fields = ['media','title','subtitle','content','url',]
        
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
    
        for field in self.fields.values():
            field.widget.attrs['placeholder'] = field.label
            field.label = False
            self.fields['media'].widget.attrs.update(
                {'class': 'form-control'})
            
    def clean_title(self):
        title = self.cleaned_data["title"]
        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', title):
            raise forms.ValidationError(_("The title contains unauthorized characters."))

        if not title:
            raise forms.ValidationError(_("The title is required."))

        return title

    def clean_subtitle(self):
        subtitle = self.cleaned_data["subtitle"]

        if not subtitle:
            raise forms.ValidationError(_("The subtitle is required."))

        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', subtitle):
            raise forms.ValidationError(_("The subtitle contains unauthorized characters."))

        return subtitle

    def clean_content(self):
        content = self.cleaned_data["content"]
        clean_content=caption_optimizer(content)
        
        if not content:
            raise forms.ValidationError(_("The content is required."))

        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', clean_content):
            raise forms.ValidationError(_("The content contains unauthorized characters."))

        return content
    
    def clean_media(self):
        image = self.cleaned_data["media"]

        if not image:
            raise forms.ValidationError(_("The image container cannot be empty."))

        image_format = imghdr.what(image)
        if image_format not in ['jpeg', 'png']:
            raise forms.ValidationError(_("The image format is not valid. Only JPEG and PNG files are allowed."))

        return image

    def clean_url(self):
        url = self.cleaned_data["url"]

        if not url:
            raise forms.ValidationError(_("The URL is required."))
        
        validate = URLValidator()
        try:
            validate(url)
        except ValidationError:
            raise forms.ValidationError("La URL no es válida.")
        return url

class RedirectContentForm(forms.ModelForm):

    class Meta:
        model = Content
        fields = ['media','title','subtitle','url',]
        
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
    
        for field in self.fields.values():
            field.widget.attrs['placeholder'] = field.label
            field.label = False
            self.fields['media'].widget.attrs.update(
                {'class': 'form-control'})
            
    def clean_title(self):
        title = self.cleaned_data["title"]

        if not title:
            raise forms.ValidationError(_("The title is required."))
        
        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', title):
            raise forms.ValidationError(_("The title contains unauthorized characters."))

        return title

    def clean_subtitle(self):
        subtitle = self.cleaned_data["subtitle"]

        if not subtitle:
            raise forms.ValidationError(_("The subtitle is required."))

        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', subtitle):
            raise forms.ValidationError(_("The subtitle contains unauthorized characters."))

        return subtitle

    def clean_content(self):
        content = self.cleaned_data["content"]
        clean_content=caption_optimizer(content)
        
        if not content:
            raise forms.ValidationError(_("The content is required."))

        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', clean_content):
            raise forms.ValidationError(_("The content contains unauthorized characters."))

        return content
    
    def clean_media(self):
        image = self.cleaned_data["media"]

        if not image:
            raise forms.ValidationError(_("The image container cannot be empty."))

        image_format = imghdr.what(image)
        if image_format not in ['jpeg', 'png']:
            raise forms.ValidationError(_("The image format is not valid. Only JPEG and PNG files are allowed."))

        return image

    def clean_url(self):
        url = self.cleaned_data["url"]

        if not url:
            raise forms.ValidationError(_("The URL is required."))
        
        validate = URLValidator()
        try:
            validate(url)
        except ValidationError:
            raise forms.ValidationError("La URL no es válida.")
        return url

class StickerContentForm(forms.ModelForm):

    class Meta:
        model = Content
        fields = ['media','url']
        
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
    
        for field in self.fields.values():
            field.widget.attrs['placeholder'] = field.label
            field.label = False
            self.fields['media'].widget.attrs.update(
                {'class': 'form-control'})
        
    def clean_media(self):
        image = self.cleaned_data["media"]

        if not image:
            raise forms.ValidationError(_("The image container cannot be empty."))

        image_format = imghdr.what(image)
        if image_format not in ['jpeg', 'png']:
            raise forms.ValidationError(_("The image format is not valid. Only JPEG and PNG files are allowed."))

        return image

    def clean_url(self):
        url = self.cleaned_data["url"]

        if not url:
            raise forms.ValidationError(_("The URL is required."))
        
        validate = URLValidator()
        try:
            validate(url)
        except ValidationError:
            raise forms.ValidationError("La URL no es válida.")
        return url
            
class GalleryForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['image'].widget.attrs.update(
                {'class': 'form-control'})
    class Meta:
        model = ImageGallery
        fields = ['image'] 

class BulletSimpleForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

        for field in self.fields.values():
            field.widget.attrs['placeholder'] = field.label
            field.label = False

    class Meta:
        model = DynamicBullets
        fields = ['bullet_title','content_bullet'] 

class ImageContentForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['media'].widget.attrs.update(
                {'class': 'form-control'})

    class Meta:
        model = Content
        fields = ['media'] 

class FAQForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
    
        for field in self.fields.values():
            field.widget.attrs['placeholder'] = field.label
            field.label = False
            self.fields['status'].widget.attrs.update(
                {'class': 'custom-select custom-select-sm'})
            self.fields['legal'].widget.attrs.update(
                {'class': 'custom-select custom-select-sm'})
            
    class Meta:
        model = FAQ
        fields = '__all__'
        exclude = ('author','lang',)
    
    def clean_title(self):
        title = self.cleaned_data.get('title')
        
        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', title):
            raise forms.ValidationError(_("The title contains unauthorized characters."))

        if not title:
            raise forms.ValidationError(_("The title is required."))

        return title

class SetFaqForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
    
        for field in self.fields.values():
            field.widget.attrs['placeholder'] = field.label
            field.label = False

    class Meta:
        model = SetFaq
        fields = '__all__'
        exclude = ('faq',)
    
    def clean_question(self):
        question = self.cleaned_data["question"]

        if not question:
            raise forms.ValidationError(_("The question is required."))

        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', question):
            raise forms.ValidationError(_("The question contains unauthorized characters."))

        return question

    def clean_answer(self):
        answer = self.cleaned_data["answer"]
        clean_content=caption_optimizer(answer)

        if not answer:
            raise forms.ValidationError(_("The answer is required."))
        
        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', clean_content):
            raise forms.ValidationError(_("The answer contains unauthorized characters."))

        return answer

class BlogForm(forms.ModelForm):

    class Meta:
        model = Content
        fields = ['status','category','title','subtitle','content','media','folder_doc',]
        
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
    
        for field in self.fields.values():
            field.widget.attrs['placeholder'] = field.label
            field.label = False
        self.fields['media'].widget.attrs.update(
            {'class': 'form-control'})
        self.fields['folder_doc'].widget.attrs.update(
            {'class': 'form-control'})
            
            
    def clean_title(self):
        title = self.cleaned_data["title"]

        if not title:
            raise forms.ValidationError(_("The title is required."))
        
        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', title):
            raise forms.ValidationError(_("The title contains unauthorized characters."))

        return title

    def clean_subtitle(self):
        subtitle = self.cleaned_data["subtitle"]

        if not subtitle:
            raise forms.ValidationError(_("The subtitle is required."))

        if not re.match(r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$', subtitle):
            raise forms.ValidationError(_("The subtitle contains unauthorized characters."))

        return subtitle

    def clean_content(self):
        content = self.cleaned_data.get('content')
        if not content:
            raise forms.ValidationError(_("The content is required."))
    
        message_formatted = caption_optimizer(content)
        print(message_formatted)
        regex = r"^[a-zA-Z0-9\s.,#-ñÑáéíóúÁÉÍÓÚ]*$"
        match = re.match(regex, message_formatted, re.DOTALL)
        if not match:
            raise forms.ValidationError(_("The content contains unauthorized characters."))
        
        return content
    
    def clean_media(self):
        image = self.cleaned_data["media"]

        if not image:
            raise forms.ValidationError(_("The image container cannot be empty."))

        image_format = imghdr.what(image)
        if image_format not in ['jpeg', 'png']:
            raise forms.ValidationError(_("The image format is not valid. Only JPEG and PNG files are allowed."))

        return image
    
    def clean_folder_doc(self):
        doc = self.cleaned_data["folder_doc"]
        if not doc:
            pass
        else:
            if not doc.name.endswith('.pdf'):
                raise forms.ValidationError("El archivo debe ser en formato PDF.")

        return doc

    def clean_url(self):
        url = self.cleaned_data["url"]

        if not url:
            raise forms.ValidationError(_("The URL is required."))
        
        validate = URLValidator()
        try:
            validate(url)
        except ValidationError:
            raise forms.ValidationError("La URL no es válida.")
        return url
    
#user
class DataEmailForm(forms.ModelForm):
    class Meta:
        model = DataEmail
        fields = ['email']
    
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['email'].label = ''
        self.fields['email'].widget.attrs.update(
            {'placeholder': _('Place Your Email')})
        
class CompanyForm(forms.ModelForm):
    class Meta: 
        model = Company
        fields = '__all__'
        exclude = ('owner','city_legal','lang','business')
    
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        for field in self.fields.values():
            field.widget.attrs['placeholder'] = field.label
            field.label = False
            field.required = True
            self.fields['logo'].widget.attrs.update(
                {'class': 'form-control'})
    
    def clean_email(self):
        email = self.cleaned_data.get('email')
        epattern = r"^[a-zA-Z0-9_.+-]+@[a-zA-Z0-9-]+\.[a-zA-Z0-9-.]+$"
        if not re.match(epattern, email):
            raise forms.ValidationError(_('Please enter a valid email.'))
        return email

    def clean_phone(self):
        phone=self.cleaned_data.get('phone')
        s = str(phone)
        clean_string = s.replace(" ", "").replace("-", "")
        pattern = r'^\+[\d\s]{10,12}$'
        if not re.match(pattern, clean_string):
            raise forms.ValidationError(_('Only this format is allowed (+123456789)'))
        else:
            clean_number = phonenumbers.parse(clean_string, None)
            if phonenumbers.is_possible_number(clean_number):
                return phone
            else:
                raise forms.ValidationError(_('This phonenumber is not valid'))
    
    def clean_name(self):
        name = self.cleaned_data.get('name')
        tpattern = r"^[a-zA-Z0-9\-/., ]*$" 
        if not re.match(tpattern, name):
            raise forms.ValidationError(_('Special characters are not allowed.'))
        return name

    def clean_web(self):
        web = self.cleaned_data.get('web')
        return web

    def clean_address(self):
        address = self.cleaned_data.get('address')
        message_formatted = caption_optimizer(address)

        if not address:
            raise forms.ValidationError(_("The content is required."))
        
        regex = r'^[a-zA-Z0-9\s!.,?;:"\'áéíóúÁÉÍÓÚñÑüÜ]+$'
        if not re.match(regex, message_formatted):
            raise forms.ValidationError(_('Special characters are not allowed.'))
        return address

class SocialMediaForm(forms.ModelForm):
    class Meta: 
        model = SocialLinks
        fields = '__all__'
        exclude = ('parent',)

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        for field in self.fields.values():
            field.widget.attrs['placeholder'] = field.label
            field.label = False
    
class CommentsFormBlog(forms.ModelForm):
    class Meta: 
        model = Comments
        fields = '__all__'
    
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields["post"].disabled = True
        self.fields["name"].disabled = True
        self.fields["email"].disabled = True
        self.fields["host"].disabled = True
        self.fields["message"].disabled = True
        
class UserForm(forms.ModelForm):
    class Meta:
        model = UserBase
        exclude = ('about','zip','image','password','last_login','is_staff')
        fields = '__all__'
        
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['city_profile'].queryset = City.objects.none()
        self.fields['email'].disabled = True
        self.fields['username'].disabled = True
        self.fields['cloud_id'].required = False
        
        if 'country_profile' in self.data:
            try:
                country_id = int(self.data.get('country_profile'))
                self.fields['city_profile'].queryset = City.objects.filter(country_id=country_id).order_by('name')
            except (ValueError, TypeError):
                pass  # invalid input from the client; ignore and fallback to empty City queryset
        elif self.instance.pk:
            try:
                self.fields['city_profile'].queryset = self.instance.country_profile.city_set.all()
            except:
                self.fields['city_profile'].queryset = City.objects.none()
        
class ResponseContactForm(forms.ModelForm):
    class Meta:
        model = ContactResponse
        fields = ['message']

class ResponseContactFormDisabled(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['message'].disabled = True

    class Meta:
        model = ContactResponse
        fields = ['message']
#linkzone
# class DynamicSecForm(forms.ModelForm):
#     class Meta:
#         model = Lobby
#         fields = '__all__'


class SiteNewsForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['media'].widget.attrs.update(
                {'class': 'form-control'})
    class Meta:
        model = Content
        fields = ['status', 'title', 'media', 'subtitle', 'content', 'url']

class FAQSiteForm(forms.ModelForm):
    class Meta:
        model = FAQ
        fields = '__all__'
        
#Email_Marketing
class NewsletterForm(forms.ModelForm):
    
    class Meta: 
        model = DataEmail
        fields = ['email']

    def clean_email(self):
        email = self.cleaned_data['email']
        pattern = re.compile(r'^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$')
        if not email:
            raise ValidationError(_('Email is required.'))
        elif DataEmail.objects.filter(email=email).exists():
            raise ValidationError(_('This email is already subscribed.'))
        elif not pattern.match(email):
            raise ValidationError(_('The email address is not valid.'))
        return email
    
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['email'].widget.attrs.update(
            {'class': 'form-control required email bg-white border-0', 'placeholder': _('Place Email')})
        self.fields['email'].label=False
        
#orders 


# class CommentForm(forms.ModelForm):
#     class Meta: 
#         model = Comment
#         fields = ['user','status','comment','rate',]

#     def __init__(self, *args, **kwargs):
#         super().__init__(*args, **kwargs)
#         self.fields["user"].disabled = True
#         self.fields["comment"].disabled = True
#         self.fields["rate"].disabled = True

#Stela Payments
class WalletForm(forms.ModelForm):
    class Meta: 
        model = Wallet
        exclude = ('user',)
        fields = '__all__'

#Post Facebook
class DateInput(forms.DateInput):
    input_type = 'date'

class FbPostForm(forms.ModelForm):

    class Meta:
        model=FacebookPostPage
        exclude = ('page' 'feed_id',)
        fields = '__all__'
        widgets = {
            'schedule': DateInput()
        }
           
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['content'].label=False
        self.fields["content"].required = False
        self.fields['content'].widget.attrs.update(
            {'onchange': 'submitTrigger()'})
        self.fields["schedule"].required = False
        self.fields["schedule"].label = False
        self.fields['schedule'].widget.attrs.update({'min': date.today() + timedelta(days=1), 'max': (date.today() + timedelta(days=180)).strftime('%Y-%m-%d')})
        
class FacebookMediaForm(forms.ModelForm):

    class Meta:
        model = FacebookPostMedia
        exclude = ('post',)
        fields = '__all__'

class FacebookEventsForm(forms.ModelForm):

    class Meta:
        model = FacebookPageEvent
        exclude = ('owner',)
        fields = '__all__'
        widgets = {
            'start_time': DateInput(),
            'end_time': DateInput(),

        }
    
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['status'].label = False
        self.fields['type'].label = False
        self.fields['category'].label = False
        self.fields['name'].label = False
        self.fields['start_time'].label = False
        self.fields['description'].label = False
        self.fields['description'].required = False
        self.fields['cover'].label = False
        self.fields['cover'].widget.attrs.update(
            {'class': 'form-control'})
        self.fields['description'].widget.attrs.update(
            {'class': 'vh-20'})
        self.fields['start_time'].widget.attrs.update({'min': date.today() + timedelta(days=1), 'max': (date.today() + timedelta(days=180)).strftime('%Y-%m-%d')})

class IGPostForm(forms.ModelForm):

    class Meta:
        model=IGPost
        exclude = ('parent',)
        fields = '__all__'
    
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['status'].label = False
        self.fields['mediatype'].label = False
        self.fields['caption'].label = False
        self.fields['schedule'].label = False
        self.fields['status'].widget.attrs.update(
            {'class': 'custom-select custom-select-sm'})
        self.fields['mediatype'].widget.attrs.update(
            {'class': 'custom-select custom-select-sm'})

class IGMediaForm(forms.ModelForm):

    class Meta:
        model=IGMediaContent
        exclude = ('post',)
        fields = '__all__'
    
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['cover'].widget.attrs.update(
                {'class': 'form-control', 'accept': '.jpg'})
        self.fields['media'].widget.attrs.update(
                {'class': 'form-control', 'accept': '.mp4'})

class SendGridForm(forms.Form):
    email = forms.EmailField(label=_('To Email'))
    subject = forms.CharField(label=_('Subject'))
    client = forms.CharField(label=_('Client or Brand'))
    message = forms.CharField(widget=forms.Textarea, label=_('Report'), required=False)

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        for field in self.fields.values():
            field.widget.attrs['placeholder'] = field.label
            field.label = False
        
    def clean_email(self):
        email = self.cleaned_data.get('email')
        epattern = r"^[a-zA-Z0-9_.+-]+@[a-zA-Z0-9-]+\.[a-zA-Z0-9-.]+$"
        if not re.match(epattern, email):
            raise forms.ValidationError(_('Please enter a valid email.'))
        return email

    def clean_subject(self):
        subject = self.cleaned_data.get('subject')
        tpattern = r"^[a-zA-Z0-9\-/., ñÑáéíóúÁÉÍÓÚ]*$"
        if not re.match(tpattern, subject):
            raise forms.ValidationError(_('Special characters are not allowed.'))
        return subject

    def clean_client(self):
        client = self.cleaned_data.get('client')
        tpattern = r"^[a-zA-Z0-9\-/., ñÑáéíóúÁÉÍÓÚ]*$"
        if not re.match(tpattern, client):
            raise forms.ValidationError(_('Special characters are not allowed.'))
        return client

    def clean_message(self):
        message = self.cleaned_data.get('message')
        message_formatted = caption_optimizer(message)
        print(message_formatted)
        regex = r"^[a-zA-Z0-9\s.,#-ñÑáéíóúÁÉÍÓÚ]*$"
        match = re.match(regex, message_formatted, re.DOTALL)
        if not match:
            print('not validated')
            raise forms.ValidationError(_('Special characters are not allowed.'))
        return message

class ReviewsForm(forms.ModelForm):
    class Meta:
        model = Reviews
        fields = ['message', 'rate']

#siteapp Forms
class LiteraryWorkForm(forms.ModelForm):
    class Meta:
        model = LiteraryWork
        fields = ('title', 'author', 'publication_date', 'genre', 'synopsis')
    
    def clean_title(self):
        title = self.cleaned_data['title']
        if len(title) < 5:
            raise forms.ValidationError(_("El title must be at least 5 characters."))
        return title

    def clean_publication_date(self):
        publication_date = self.cleaned_data['publication_date']
        if publication_date.year < 1800:
            raise forms.ValidationError(_("The pub date must be after 1800"))
        return publication_date

class ResourceForm(forms.ModelForm):
    class Meta:
        model = Resource
        fields = ['title', 'file']

class BillFileForm(forms.ModelForm):
    class Meta:
        model = BillFile
        fields = ['title', 'pdf', 'comments']


# Generated by Django 4.2.1 on 2023-11-13 02:39

import datetime
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('cloud', '0001_initial'),
        ('geolocation', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='BillingRecipt',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_generated', models.BooleanField(default=False)),
                ('is_budget', models.BooleanField(default=False)),
                ('status', models.CharField(default='Pending', max_length=60)),
                ('payment_option', models.CharField(blank=True, max_length=200, null=True)),
                ('option', models.CharField(choices=[('Others', 'Others'), ('Billing receipt', 'Billing receipt'), ('budget_design', 'Budget Design'), ('Monthly charge', 'Monthly charge'), ('budget_development', 'Budget Development'), ('budget_marketing', 'Budget Marketing')], max_length=60, null=True, verbose_name='Case')),
                ('report', models.TextField(null=True, verbose_name='Report')),
                ('amount', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('discount', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('tax', models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
            ],
        ),
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('type', models.CharField(choices=[('woman', 'woman'), ('male', 'male'), ('curvy', 'curvy'), ('kids', 'kids'), ('furniture', 'furniture'), ('Select Type', 'Select Type')], default='Select Type', max_length=30, verbose_name='Type')),
                ('title', models.CharField(max_length=50, verbose_name='Title')),
                ('slug', models.SlugField(help_text='Required', max_length=255)),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('lang', models.CharField(default='en', max_length=80)),
                ('owner', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='Company',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200, verbose_name='Startup Name')),
                ('business', models.CharField(blank=True, choices=[('Consulting', 'Consulting'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('Health and Wellness', 'Health and Wellness'), ('Education and Training', 'Education and Training'), ('IT Development Services', 'IT Development Services'), ('Restaurants and Food Services', 'Restaurants and Food Services'), ('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('Media Creators', 'Media Creators'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('E-commerce', 'E-commerce')], max_length=100, null=True, verbose_name='Business Type')),
                ('logo', models.ImageField(upload_to='brands/', verbose_name='Brand Logo')),
                ('description', models.TextField()),
                ('web', models.URLField(verbose_name='Website')),
                ('email', models.EmailField(max_length=200, verbose_name='Contact email')),
                ('phone', models.CharField(max_length=20)),
                ('address', models.TextField()),
                ('lang', models.CharField(default='en', max_length=80)),
                ('created', models.DateField(auto_now_add=True)),
                ('city_legal', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='geolocation.city')),
                ('country_legal', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='geolocation.country', verbose_name='Country')),
                ('owner', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='company', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='Contact',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(choices=[('Answered', 'Answered'), ('No Answered', 'No Answered')], default='No Answered', max_length=20, verbose_name='Status')),
                ('name', models.CharField(max_length=150, null=True)),
                ('host', models.CharField(default='no host catched', max_length=150)),
                ('email', models.EmailField(max_length=254, verbose_name='Email')),
                ('subject', models.CharField(max_length=150, verbose_name='Subject')),
                ('message', models.TextField(verbose_name='Message')),
            ],
        ),
        migrations.CreateModel(
            name='Content',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('category', models.CharField(blank=True, choices=[('Interviews', 'Interviews'), ('Inspiration', 'Inspiration'), ('Events and Conferences', 'Events and Conferences'), ('Tips and Tricks', 'Tips and Tricks'), ('Guides and Manuals', 'Guides and Manuals'), ('Tutorials', 'Tutorials'), ('News', 'News')], default='News', max_length=100)),
                ('card', models.CharField(blank=True, choices=[('card-tale', 'card-tale'), ('card-light-danger', 'card-light-danger'), ('card-dark-blue', 'card-dark-blue'), ('card-light-blue', 'card-light-blue')], max_length=50, null=True, verbose_name='Color Card')),
                ('about', models.CharField(blank=True, choices=[('Mission', 'Mission'), ('Vision', 'Vision'), ('Values', 'Values')], default='Mission', max_length=60, null=True, verbose_name='Title')),
                ('section', models.CharField(default='No section', max_length=200, verbose_name='Section')),
                ('path', models.CharField(choices=[('Stela Websites', 'Stela Websites'), ('Stela Business App', 'Stela Business App'), ('Services', 'Services')], max_length=60, null=True, verbose_name='Path Title')),
                ('appstela', models.CharField(choices=[('Communications', 'Communications'), ('Sweet Content', 'Sweet Content'), ('Marketing', 'Marketing'), ('Users Control', 'Users Control'), ('Fintech', 'Fintech'), ('Inventory', 'Inventory'), ('Operations', 'Operations'), ('Maintance', 'Maintance'), ('Speed', 'Speed'), ('Workflow', 'Workflow'), ('Support', 'Support')], max_length=60, null=True, verbose_name='App Title')),
                ('tag', models.CharField(max_length=100, null=True, verbose_name='Tag')),
                ('status', models.CharField(blank=True, choices=[('Publish', 'Publish'), ('Draft', 'Draft')], default='Draft', max_length=10, null=True, verbose_name='Status')),
                ('title', models.CharField(max_length=100, verbose_name='Title')),
                ('media', models.FileField(blank=True, null=True, upload_to='media/')),
                ('folder_doc', models.FileField(blank=True, null=True, upload_to='bucket/')),
                ('subtitle', models.CharField(max_length=250, verbose_name='Subtitle')),
                ('content', models.TextField(blank=True)),
                ('slug', models.SlugField(help_text='Required', max_length=255)),
                ('lang', models.CharField(default='en', max_length=80)),
                ('url', models.CharField(max_length=100, null=True, verbose_name='url')),
                ('site', models.CharField(max_length=100, null=True, verbose_name='Website')),
                ('schedule', models.DateTimeField(blank=True, null=True)),
                ('is_schedule', models.BooleanField(default=False)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('author', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='author', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='ControlFacturacion',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('control_id', models.CharField(max_length=15)),
                ('base', models.DecimalField(decimal_places=2, max_digits=8, null=True)),
                ('iva', models.DecimalField(decimal_places=2, max_digits=8, null=True)),
                ('total', models.DecimalField(decimal_places=2, max_digits=15, null=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
            ],
        ),
        migrations.CreateModel(
            name='Customer',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('full_name', models.CharField(max_length=250, verbose_name='Full Name')),
                ('userid', models.CharField(max_length=20, verbose_name='Costumer ID')),
                ('email', models.EmailField(max_length=254, verbose_name='email')),
                ('country', models.CharField(blank=True, default='No Country', max_length=150, null=True, verbose_name='Country')),
                ('address', models.CharField(max_length=150, verbose_name='Address')),
                ('phone', models.CharField(max_length=50, verbose_name='phone_number')),
                ('owner', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='DataEmail',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('email', models.EmailField(max_length=254, unique=True)),
                ('date', models.DateTimeField(auto_now_add=True)),
            ],
        ),
        migrations.CreateModel(
            name='FacebookPage',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('fans', models.IntegerField(default=0)),
                ('followers', models.IntegerField(default=0)),
                ('name', models.CharField(max_length=250)),
                ('category', models.CharField(max_length=250)),
                ('asset_id', models.CharField(default='noid', max_length=50)),
                ('token', models.CharField(default='not_token', max_length=250)),
                ('image', models.CharField(max_length=2000)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('owner', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='FacebookPageCommentsReply',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('from_user', models.CharField(max_length=250)),
                ('comment', models.TextField()),
                ('created', models.DateTimeField(auto_now_add=True)),
            ],
        ),
        migrations.CreateModel(
            name='FacebookPageConversations',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('core_id', models.CharField(max_length=500)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('page', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='conversations', to='stela_control.facebookpage')),
            ],
        ),
        migrations.CreateModel(
            name='FAQ',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(choices=[('Draft', 'Draft'), ('Publish', 'Publish')], default='Draft', max_length=10, verbose_name='Status')),
                ('legal', models.CharField(choices=[('shipping', 'Shipping and Logistics'), ('marketplace', 'Marketplace Program'), ('product', 'Product/Service'), ('support', 'Technical Support'), ('purchase', 'Purchasing Process'), ('inquiry', 'General Inquiries')], default='shipping', max_length=28, verbose_name='Legal')),
                ('lang', models.CharField(default='en', max_length=80)),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('author', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='author_faq', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='IGPost',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('container_id', models.CharField(blank=True, default='noid', max_length=500)),
                ('feed_id', models.CharField(blank=True, default='noid', max_length=500)),
                ('token', models.CharField(blank=True, default='empty', max_length=500)),
                ('publish_status', models.CharField(blank=True, default='noid', max_length=500)),
                ('status', models.CharField(blank=True, choices=[('publish', 'Publish'), ('draft', 'Draft')], default='draft', max_length=80)),
                ('mediatype', models.CharField(blank=True, choices=[('POST', 'POST'), ('REELS', 'Reels'), ('CAROUSEL', 'Carousel'), ('STORIES', 'Stories')], default='Post', max_length=80)),
                ('caption', models.TextField(blank=True)),
                ('audioname', models.CharField(blank=True, default='Original Audio', max_length=500)),
                ('schedule', models.DateTimeField(blank=True, null=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
            ],
        ),
        migrations.CreateModel(
            name='Inventory',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(choices=[('Active', 'Active'), ('Inactive', 'Inactive')], max_length=10, verbose_name='Status')),
                ('sku', models.CharField(help_text='Required', max_length=255, verbose_name='SKU')),
                ('title', models.CharField(help_text='Required', max_length=255, verbose_name='Title')),
                ('yearly', models.BooleanField(default=False)),
                ('type', models.CharField(choices=[('Service', 'Service'), ('Product', 'Product')], default='Select Type', max_length=30, verbose_name='Type')),
                ('description', models.TextField(blank=True, help_text='No Required', verbose_name='Description')),
                ('image', models.ImageField(upload_to='inventory/', verbose_name='Image')),
                ('slug', models.SlugField(help_text='Required', max_length=255)),
                ('price', models.DecimalField(blank=True, decimal_places=2, error_messages={'name': {'max_lenght': 'The price must be between 0 and 9999.99'}}, help_text='Maximun 9999.99', max_digits=6, null=True, verbose_name='Price USD')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('lang', models.CharField(default='en', max_length=80)),
                ('category', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='products', to='stela_control.category')),
                ('owner', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ('-created',),
            },
        ),
        migrations.CreateModel(
            name='Modules',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(help_text='Required', max_length=255, verbose_name='Service')),
                ('subtitle', models.CharField(help_text='Required', max_length=255, verbose_name='Subtitle')),
                ('description', models.TextField(blank=True, help_text='No Required', verbose_name='Description')),
                ('image', models.ImageField(upload_to='services/', verbose_name='Image')),
                ('price', models.DecimalField(blank=True, decimal_places=2, error_messages={'name': {'max_lenght': 'The price must be between 0 and 9999.99'}}, help_text='Maximun 9999.99', max_digits=6, null=True, verbose_name='Price USD')),
                ('status', models.CharField(choices=[('Active', 'Active'), ('Inactive', 'Inactive')], max_length=10)),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('parent', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='modules', to='stela_control.inventory')),
            ],
        ),
        migrations.CreateModel(
            name='Order',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('section', models.CharField(choices=[('No Selected', 'No Selected'), ('Stela Websites', 'Stela Websites'), ('Cloud Domains', 'Cloud Domains'), ('Cloud Elastic Instance', 'Cloud Elastic Instance'), ('Stela Design', 'Stela Design'), ('Store', 'Store'), ('Stela Marketing', 'Stela Marketing')], default='No Selected', max_length=50)),
                ('email', models.EmailField(max_length=254, null=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('key_validator', models.CharField(max_length=200)),
                ('transaction_id', models.CharField(max_length=200, null=True)),
                ('payment_option', models.CharField(blank=True, max_length=200, null=True)),
                ('subtotal', models.DecimalField(decimal_places=2, max_digits=7, null=True)),
                ('taxes', models.DecimalField(decimal_places=2, max_digits=7, null=True)),
                ('profit', models.DecimalField(decimal_places=2, max_digits=7, null=True)),
                ('payment_fee', models.DecimalField(decimal_places=2, max_digits=7, null=True)),
                ('total_paid', models.DecimalField(decimal_places=2, max_digits=7, null=True)),
                ('status', models.CharField(choices=[('Completed', 'Completed'), ('Pending', 'Pending')], default='Pending', max_length=100)),
                ('billing', models.IntegerField(null=True)),
                ('customer', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='stela_control.customer')),
                ('owner', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ('-created',),
            },
        ),
        migrations.CreateModel(
            name='PaypalClient',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
        ),
        migrations.CreateModel(
            name='SiteControl',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('ip', models.CharField(max_length=60)),
                ('lon', models.CharField(max_length=100)),
                ('lat', models.CharField(max_length=100)),
                ('dateview', models.DateTimeField(auto_now_add=True)),
                ('pishing', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='Sizes',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('size', models.CharField(max_length=20, verbose_name='size')),
                ('owner', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='StelaColors',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=20)),
                ('code1', models.CharField(blank=True, max_length=10, null=True)),
                ('code2', models.CharField(blank=True, max_length=10, null=True)),
                ('code3', models.CharField(blank=True, max_length=10, null=True)),
                ('owner', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='Support',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('email', models.EmailField(max_length=254)),
                ('terms', models.BooleanField(verbose_name='Responsibility commitment')),
                ('message', models.TextField(verbose_name='Brief description')),
                ('option', models.CharField(choices=[('My account has an error', 'My account has an error'), ('Others', 'Others'), ('My delivery has been delayed', 'My delivery has been delayed'), ('I have a problem with my project', 'I have a problem with my project'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('Payments Issue', 'Payments Issue')], max_length=60, verbose_name='Case')),
                ('image', models.ImageField(blank=True, null=True, upload_to='cases/', verbose_name='Image (optional)')),
                ('ticket', models.CharField(max_length=60)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('status', models.CharField(choices=[('Completed', 'Completed'), ('Pending', 'Pending')], default='Pending', max_length=50, null=True)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='user_support', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
        ),
        migrations.CreateModel(
            name='Team',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(choices=[('Publish', 'Publish'), ('Draft', 'Draft')], default='Draft', max_length=10, verbose_name='Status')),
                ('full_name', models.CharField(max_length=150, verbose_name='Staff Full Name')),
                ('image', models.ImageField(upload_to='images/', verbose_name='Image')),
                ('lang', models.CharField(default='es', max_length=80)),
                ('staff', models.CharField(max_length=150, verbose_name='Staff')),
            ],
        ),
        migrations.CreateModel(
            name='TemplateSections',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('section', models.CharField(max_length=80, verbose_name='Section')),
                ('lang', models.CharField(default='en', max_length=80)),
                ('created', models.DateTimeField(auto_now_add=True)),
            ],
        ),
        migrations.CreateModel(
            name='Variants',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=100, null=True)),
                ('image', models.ImageField(null=True, upload_to='variant/', verbose_name='Image')),
                ('quantity', models.IntegerField(default=1)),
                ('price', models.DecimalField(decimal_places=2, default=0, max_digits=12)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('color', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='stela_control.stelacolors')),
                ('product', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='variants', to='stela_control.inventory')),
                ('size', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='stela_control.sizes')),
            ],
        ),
        migrations.CreateModel(
            name='WishList',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('product', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='whishlist', to='stela_control.variants')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ('-created',),
            },
        ),
        migrations.CreateModel(
            name='Wallet',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('type', models.CharField(choices=[('Paypal', 'Paypal'), ('Binance', 'Binance'), ('Zelle', 'Zelle')], max_length=100, verbose_name='Type of Wallet')),
                ('email', models.EmailField(max_length=254, unique=True, verbose_name='email')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='VariantsImage',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=255, verbose_name='Catalogue Title')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('product', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='catalog', to='stela_control.variants')),
            ],
        ),
        migrations.CreateModel(
            name='Templates',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(choices=[('Inactive', 'Inactive'), ('Active', 'Active')], default='Inactive', max_length=10, verbose_name='Status')),
                ('title', models.CharField(max_length=150, verbose_name='Title')),
                ('image', models.ImageField(upload_to='templates/', verbose_name='Image')),
                ('slug', models.SlugField(help_text='Required', max_length=255)),
                ('url', models.CharField(max_length=50, verbose_name='Url')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('integration', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='items', to='stela_control.inventory')),
            ],
        ),
        migrations.CreateModel(
            name='SupportResponse',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('response', models.TextField(verbose_name='Answer')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('case', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='stela_control.support')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='user_response', to=settings.AUTH_USER_MODEL, verbose_name='Usuario')),
            ],
        ),
        migrations.CreateModel(
            name='StelaSelection',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('validator', models.CharField(default='No user', max_length=50)),
                ('status', models.CharField(choices=[('Pending', 'Pending'), ('Checked', 'Checked'), ('Payeed', 'Payeed')], default='Pending', max_length=10)),
                ('amount', models.DecimalField(blank=True, decimal_places=2, error_messages={'name': {'max_lenght': 'The price must be between 0 and 9999.99'}}, max_digits=6, null=True)),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('domain', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='cloud.domains')),
                ('integration', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='stela_control.inventory')),
                ('template', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='templates', to='stela_control.templates')),
            ],
        ),
        migrations.CreateModel(
            name='StelaPayments',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('order', models.IntegerField(null=True)),
                ('billing', models.IntegerField(null=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('key_validator', models.CharField(max_length=200)),
                ('transaction_id', models.CharField(max_length=200, null=True)),
                ('payment_option', models.CharField(blank=True, max_length=200, null=True)),
                ('subtotal', models.DecimalField(decimal_places=2, max_digits=7, null=True)),
                ('taxes', models.DecimalField(decimal_places=2, max_digits=7, null=True)),
                ('profit', models.DecimalField(decimal_places=2, max_digits=7, null=True)),
                ('payment_fee', models.DecimalField(decimal_places=2, max_digits=7, null=True)),
                ('total_paid', models.DecimalField(decimal_places=2, max_digits=7, null=True)),
                ('host', models.CharField(max_length=200)),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ('-created',),
            },
        ),
        migrations.CreateModel(
            name='StelaItems',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('module', models.CharField(max_length=150, verbose_name='Title')),
                ('amount', models.DecimalField(blank=True, decimal_places=2, max_digits=6, null=True)),
                ('parent', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='parent', to='stela_control.stelaselection')),
            ],
        ),
        migrations.CreateModel(
            name='SocialLinks',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('social', models.CharField(choices=[('Linkedin', 'Linkedin'), ('Facebook', 'Facebook'), ('Youtube', 'Youtube'), ('X', 'X'), ('Tiktok', 'Tiktok'), ('Instagram', 'Instagram'), ('Github', 'Github')], default='No Selected', max_length=50)),
                ('url', models.CharField(max_length=80)),
                ('parent', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='socialmedia', to='stela_control.company')),
            ],
        ),
        migrations.CreateModel(
            name='SiteViews',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('host', models.CharField(default='no catch data', max_length=150)),
                ('page', models.CharField(default='page no catched', max_length=150)),
                ('views', models.IntegerField(default=0)),
                ('lastdate', models.CharField(default='no catch data', max_length=150)),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('blog', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='stela_control.content')),
                ('country', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='geolocation.country', verbose_name='Country')),
            ],
        ),
        migrations.CreateModel(
            name='SitePolicy',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=150, null=True, verbose_name='Title')),
                ('status', models.CharField(blank=True, choices=[('Publish', 'Publish'), ('Draft', 'Draft')], default='Draft', max_length=10, verbose_name='Status')),
                ('section', models.CharField(blank=True, choices=[('Cookie Policy', 'Cookie Policy'), ('Return Policy', 'Return Policy'), ('budget_design_terms', 'Budget Design Terms'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('budget_development_terms', 'Budget Development Terms'), ('Terms and Conditions', 'Terms and Conditions'), ('monthly_terms', 'Billing Terms'), ('Disclaimer', 'Disclaimer'), ('Privacy Policy', 'Privacy Policy'), ('billing_terms', 'Monthly Billing Terms')], default='Terms and Conditions', max_length=150)),
                ('lang', models.CharField(default='en', max_length=80)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('owner', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='site_docs', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='SharePosts',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('host', models.CharField(default='No title', max_length=150)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('post', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='shared', to='stela_control.content')),
            ],
        ),
        migrations.CreateModel(
            name='SetFaq',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('question', models.CharField(default='', max_length=250, verbose_name='Question')),
                ('answer', models.TextField()),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('faq', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='set_faq', to='stela_control.faq')),
            ],
        ),
        migrations.CreateModel(
            name='SendMoney',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('ipadress', models.CharField(blank=True, max_length=20)),
                ('amount', models.DecimalField(decimal_places=2, max_digits=8)),
                ('date', models.DateTimeField(auto_now_add=True)),
                ('status', models.CharField(choices=[('Completed', 'Completed'), ('Pending', 'Pending')], default='Pending', max_length=50)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
                ('wallet', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='stela_control.wallet')),
            ],
        ),
        migrations.CreateModel(
            name='Reviews',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('rate', models.IntegerField(default=1)),
                ('ip', models.CharField(blank=True, max_length=20)),
                ('status', models.CharField(choices=[('Draft', 'Draft'), ('Publish', 'Publish')], default='Draft', max_length=10)),
                ('lang', models.CharField(max_length=80)),
                ('message', models.TextField(verbose_name='Message')),
                ('create', models.DateTimeField(auto_now_add=True)),
                ('catalog', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='reviews', to='stela_control.inventory')),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='ProStelaData',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(default='No title', max_length=150)),
                ('chatbox', models.TextField(default='Empty')),
                ('storage_data', models.TextField(default='Empty')),
                ('response_time', models.DecimalField(decimal_places=2, max_digits=6)),
                ('section', models.CharField(default='custom', max_length=150)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('model', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='model_expert', to='stela_control.content')),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='prostela', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='Poll',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('question', models.TextField(verbose_name='Questions')),
                ('option_one', models.CharField(max_length=30, verbose_name='Awnser 1')),
                ('option_two', models.CharField(max_length=30, verbose_name='Awnser 2')),
                ('option_three', models.CharField(max_length=30, verbose_name='Awnser 3')),
                ('option_four', models.CharField(max_length=30, verbose_name='Awnser 4')),
                ('option_five', models.CharField(max_length=30, verbose_name='Awnser 5')),
                ('option_one_count', models.IntegerField(default=0)),
                ('option_two_count', models.IntegerField(default=0)),
                ('option_three_count', models.IntegerField(default=0)),
                ('option_four_count', models.IntegerField(default=0)),
                ('option_five_count', models.IntegerField(default=0)),
                ('dynamic_topic', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='stela_control.content')),
            ],
        ),
        migrations.CreateModel(
            name='PetData',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, verbose_name="Pet's name")),
                ('image', models.ImageField(upload_to='images/', verbose_name='Image')),
                ('family', models.CharField(choices=[('Dog', 'Dog')], help_text='Choose Please', max_length=10, verbose_name='Pet Family')),
                ('allergy', models.BooleanField(default=False, verbose_name="It's Allergic?")),
                ('reactive', models.CharField(blank=True, max_length=250, null=True, verbose_name='Product React')),
                ('weight', models.CharField(choices=[('1 to 10', '1 to 10'), ('10 to 25', '10 to 25'), ('26 to 40', '26 to 40'), ('41 to 70', '41 to 70'), ('71 to 91', '71 to 91'), ('91 +', '91 +')], help_text='Choose Please', max_length=40, verbose_name='Weght LBS')),
                ('breed', models.CharField(choices=[('Short Coat Breeds', 'Short Coat Breeds'), ('Wire Coat Breeds', 'Wire Coat Breeds'), ('Soft Coat Breeds', 'Soft Coat Breeds'), ('Double Coat Breeds', 'Double Coat Breeds'), ('Doodles Breeds', 'Doodles Breeds')], help_text='Choose Please', max_length=80, verbose_name='Pet Breed')),
                ('price', models.DecimalField(blank=True, decimal_places=2, error_messages={'name': {'max_lenght': 'The price must be between 0 and 999.99'}}, help_text='Maximun 999.99', max_digits=5, null=True, verbose_name='Regular price USD')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('owner', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='pet_owner', to=settings.AUTH_USER_MODEL)),
                ('parent', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='pet_service', to='stela_control.inventory')),
            ],
        ),
        migrations.CreateModel(
            name='PathControl',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('step', models.CharField(choices=[('Step 4', 'Step 4'), ('Step 3', 'Step 3'), ('Step 2', 'Step 2')], default='No Selected', max_length=50)),
                ('superuser', models.CharField(max_length=200, null=True)),
                ('password', models.CharField(max_length=200, null=True)),
                ('url', models.CharField(max_length=200, null=True)),
                ('order', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='path', to='stela_control.order')),
            ],
        ),
        migrations.CreateModel(
            name='OrderItems',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('nameitem', models.CharField(max_length=200)),
                ('amount', models.DecimalField(blank=True, decimal_places=2, max_digits=6, null=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('order', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='purchases', to='stela_control.order')),
                ('product', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='stela_control.variants')),
                ('service', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='stela_control.modules')),
                ('stela_selection', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='stela_control.stelaselection')),
            ],
        ),
        migrations.CreateModel(
            name='Notifications',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(default='No Read', max_length=200)),
                ('title', models.CharField(max_length=200)),
                ('description', models.CharField(max_length=200)),
                ('section', models.CharField(max_length=200)),
                ('url', models.CharField(max_length=200)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='Newsletter',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('template', models.CharField(choices=[('Style Template 4', 'Style Template 4'), ('Style Template 2', 'Style Template 2'), ('Style Template 3', 'Style Template 3'), ('Style Template 1', 'Style Template 1')], max_length=60, null=True, verbose_name='Style')),
                ('subject', models.CharField(max_length=250, verbose_name='Subject')),
                ('body', models.TextField(verbose_name='Messages')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('status', models.CharField(choices=[('Send', 'Send'), ('Draft', 'Draft')], max_length=20)),
                ('email', models.ManyToManyField(to='stela_control.dataemail', verbose_name='Emails')),
                ('owner', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='lead', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='ModuleItems',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('amount', models.DecimalField(decimal_places=2, max_digits=8)),
                ('qty', models.IntegerField(default=1, verbose_name='Qty')),
                ('field', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='stela_control.modules')),
                ('recipt', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='modules', to='stela_control.billingrecipt')),
            ],
        ),
        migrations.CreateModel(
            name='LegalProvision',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('clause', models.CharField(max_length=150, verbose_name='Clause')),
                ('clause_content', models.TextField(blank=True, verbose_name='Content')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('policy', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='content', to='stela_control.sitepolicy')),
            ],
        ),
        migrations.CreateModel(
            name='ItemServices',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('amount', models.DecimalField(decimal_places=2, max_digits=8)),
                ('qty', models.IntegerField(default=1, verbose_name='Qty')),
                ('field', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='stela_control.modules')),
                ('recipt', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='service_recipt', to='stela_control.billingrecipt')),
            ],
        ),
        migrations.CreateModel(
            name='ItemProducts',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('amount', models.DecimalField(decimal_places=2, max_digits=8)),
                ('qty', models.IntegerField(default=1, verbose_name='Qty')),
                ('field', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='stela_control.variants')),
                ('recipt', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='product_recipt', to='stela_control.billingrecipt')),
            ],
        ),
        migrations.CreateModel(
            name='ItemDiscount',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('field', models.CharField(choices=[('No Selected', 'No Selected'), ('Stela Payment Free Suscription', 'Stela Payment Free Suscription'), ('Promotional Discount', 'Promotional Discount'), ('Initial Payment', 'Initial Payment')], max_length=60)),
                ('amount', models.DecimalField(decimal_places=2, max_digits=8)),
                ('recipt', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='discounts', to='stela_control.billingrecipt')),
            ],
        ),
        migrations.CreateModel(
            name='ItemCloud',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('amount', models.DecimalField(decimal_places=2, max_digits=8)),
                ('qty', models.IntegerField(default=1, verbose_name='Qty')),
                ('field', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='cloud.usagecloud')),
                ('recipt', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='cloud_recipt', to='stela_control.billingrecipt')),
            ],
        ),
        migrations.CreateModel(
            name='InvoiceControl',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('control_id', models.CharField(default='Not ID', max_length=20)),
                ('section', models.CharField(max_length=200, null=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('order', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='stela_control.order')),
                ('recipt', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='billing_control', to='stela_control.billingrecipt')),
            ],
        ),
        migrations.CreateModel(
            name='InstagramAccount',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('commerce_id', models.CharField(default='no_commerce', max_length=250)),
                ('followers', models.IntegerField(default=0)),
                ('title', models.CharField(max_length=250)),
                ('username', models.CharField(max_length=250)),
                ('asset_id', models.CharField(default='noid', max_length=50)),
                ('image', models.CharField(max_length=2000)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('owner', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='ImageGallery',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image', models.ImageField(upload_to='gallery/', verbose_name='Image')),
                ('parent', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='stela_control.content')),
            ],
        ),
        migrations.CreateModel(
            name='IGUserTag',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('igname', models.CharField(blank=True, default='noid', max_length=200)),
                ('post', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='stela_control.igpost')),
            ],
        ),
        migrations.CreateModel(
            name='IGStoriesMetric',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('exits', models.IntegerField(blank=True, default=0)),
                ('impressions', models.IntegerField(blank=True, default=0)),
                ('replies', models.IntegerField(blank=True, default=0)),
                ('taps_forward', models.IntegerField(blank=True, default=0)),
                ('taps_back', models.IntegerField(blank=True, default=0)),
                ('post', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='metric_stories', to='stela_control.igpost')),
            ],
        ),
        migrations.CreateModel(
            name='IGReelMetric',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('comments', models.IntegerField(blank=True, default=0)),
                ('likes', models.IntegerField(blank=True, default=0)),
                ('plays', models.IntegerField(blank=True, default=0)),
                ('reach', models.IntegerField(blank=True, default=0)),
                ('saved', models.IntegerField(blank=True, default=0)),
                ('shares', models.IntegerField(blank=True, default=0)),
                ('total_interactions', models.IntegerField(blank=True, default=0)),
                ('post', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='metric_reel', to='stela_control.igpost')),
            ],
        ),
        migrations.CreateModel(
            name='IGPostMetric',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('engagement', models.IntegerField(blank=True, default=0)),
                ('impressions', models.IntegerField(blank=True, default=0)),
                ('reach', models.IntegerField(blank=True, default=0)),
                ('saved', models.IntegerField(blank=True, default=0)),
                ('video_views', models.IntegerField(blank=True, default=0)),
                ('post', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='metric_post', to='stela_control.igpost')),
            ],
        ),
        migrations.AddField(
            model_name='igpost',
            name='parent',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='media', to='stela_control.instagramaccount'),
        ),
        migrations.CreateModel(
            name='IGMediaContent',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('media', models.FileField(blank=True, null=True, upload_to='igmedia/')),
                ('cover', models.FileField(blank=True, null=True, upload_to='igcover/')),
                ('post', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='igitem', to='stela_control.igpost')),
            ],
        ),
        migrations.CreateModel(
            name='IGCarouselMetric',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('album_engagement', models.IntegerField(blank=True, default=0)),
                ('album_impressions', models.IntegerField(blank=True, default=0)),
                ('album_reach', models.IntegerField(blank=True, default=0)),
                ('album_saved', models.IntegerField(blank=True, default=0)),
                ('album_video_views', models.IntegerField(blank=True, default=0)),
                ('post', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='metric_carousel', to='stela_control.igpost')),
            ],
        ),
        migrations.CreateModel(
            name='Gallery',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('type', models.CharField(choices=[('Product Detail', 'Product Detail'), ('Product Description', 'Product Description')], default='Select Type', max_length=30, verbose_name='Type')),
                ('title', models.CharField(default='No selected', max_length=255)),
                ('image', models.ImageField(blank=True, upload_to='product/')),
                ('catalogue', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='img', to='stela_control.variantsimage')),
            ],
        ),
        migrations.CreateModel(
            name='FormsetFAQ',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('question', models.CharField(max_length=150, verbose_name='Questions')),
                ('response', models.TextField(verbose_name='Answer')),
                ('faq', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='fitems', to='stela_control.faq')),
            ],
        ),
        migrations.CreateModel(
            name='FacturaItems',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('order', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='compra', to='stela_control.controlfacturacion')),
                ('origin', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='stela_control.order')),
                ('recipt', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='stela_control.invoicecontrol')),
            ],
        ),
        migrations.CreateModel(
            name='FacebookPostPage',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('feed_id', models.CharField(blank=True, default='noid', max_length=500)),
                ('content', models.TextField()),
                ('schedule', models.DateTimeField(blank=True, null=True)),
                ('is_video', models.BooleanField(default=False)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('page', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='page', to='stela_control.facebookpage')),
            ],
        ),
        migrations.CreateModel(
            name='FacebookPostMedia',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('media', models.FileField(blank=True, null=True, upload_to='fb_media/')),
                ('post', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='stela_control.facebookpostpage')),
            ],
        ),
        migrations.CreateModel(
            name='FacebookPageShares',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('from_user', models.CharField(max_length=250)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('post', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='stela_control.facebookpostpage')),
            ],
        ),
        migrations.CreateModel(
            name='FacebookPageMessages',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('from_message', models.CharField(max_length=250)),
                ('to_message', models.CharField(max_length=250)),
                ('message', models.TextField()),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('conversation', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='stela_control.facebookpageconversations')),
            ],
        ),
        migrations.CreateModel(
            name='FacebookPageLikes',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('from_user', models.CharField(max_length=250)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('post', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='stela_control.facebookpostpage')),
            ],
        ),
        migrations.CreateModel(
            name='FacebookPageImpressions',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('qty', models.IntegerField(default=0)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('page', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='impressions', to='stela_control.facebookpage')),
            ],
        ),
        migrations.CreateModel(
            name='FacebookPageEvent',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(choices=[('active', 'Scheduled'), ('is_canceled', 'Cancel Event'), ('is_draft', 'Draft'), ('is_online', 'Online')], default='Select Type', max_length=80)),
                ('type', models.CharField(choices=[('', 'Select Type'), ('private', 'Private'), ('public', 'Public'), ('group', 'Group'), ('community', 'Community'), ('friends', 'Friends'), ('work_company', 'Work Company')], default='Scheduled', max_length=80)),
                ('category', models.CharField(choices=[('', 'Select Category'), ('CLASSIC_LITERATURE', 'Classic Literature'), ('COMEDY', 'Comedy'), ('CRAFTS', 'Crafts'), ('DANCE', 'Dance'), ('DRINKS', 'Drinks'), ('FITNESS_AND_WORKOUTS', 'Fitness & Workouts'), ('FOODS', 'Foods'), ('GAMES,', 'Games'), ('GARDENING', 'Gardening'), ('HEALTH_AND_MEDICAL', 'Health & Medical'), ('HEALTHY_LIVING_AND_SELF_CARE', 'Healthy Living & Self Care'), ('HOME_AND_GARDEN', 'Home & Garden'), ('MUSIC_AND_AUDIO', 'Music & Audio'), ('PARTIES', 'Parties'), ('PROFESSIONAL_NETWORKING', 'Professional Networking'), ('RELIGIONS', 'Religions'), ('SHOPPING_EVENT', 'Shopping Event'), ('SOCIAL_ISSUES', 'Social Issues'), ('SPORTS', 'Sports'), ('THEATER', 'Theater'), ('TV_AND_MOVIES', 'Tv & Movies'), ('VISUAL_ARTS', 'Visual Arts')], default='Select Category', max_length=80)),
                ('name', models.CharField(max_length=250)),
                ('start_time', models.DateField()),
                ('description', models.TextField(blank=True)),
                ('cover', models.ImageField(upload_to='events/')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('page', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='events', to='stela_control.facebookpage')),
            ],
        ),
        migrations.CreateModel(
            name='FacebookPageComments',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('from_user', models.CharField(max_length=250)),
                ('from_user_id', models.CharField(max_length=500)),
                ('comment', models.CharField(max_length=2000)),
                ('comment_id', models.CharField(max_length=500)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('update_rate', models.DateTimeField(default=datetime.datetime(2023, 11, 12, 23, 38, 54, 893584))),
                ('post', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='stela_control.facebookpostpage')),
            ],
        ),
        migrations.CreateModel(
            name='DynamicBullets',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('icon', models.CharField(blank=True, max_length=250, null=True, verbose_name='Icon')),
                ('percentaje', models.IntegerField(blank=True, default=0, null=True)),
                ('quantity', models.IntegerField(blank=True, default=0, null=True)),
                ('bullet_title', models.CharField(max_length=250, null=True, verbose_name='Bullet Title')),
                ('content_bullet', models.TextField(null=True, verbose_name='Content Bullet')),
                ('parent', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bullet_content', to='stela_control.content')),
            ],
        ),
        migrations.AddField(
            model_name='controlfacturacion',
            name='customer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='stela_control.customer'),
        ),
        migrations.AddField(
            model_name='controlfacturacion',
            name='order',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='stela_control.order'),
        ),
        migrations.AddField(
            model_name='controlfacturacion',
            name='origin',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='control', to='stela_control.billingrecipt'),
        ),
        migrations.AddField(
            model_name='controlfacturacion',
            name='owner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='content',
            name='parent',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='template', to='stela_control.templatesections', verbose_name='Parent'),
        ),
        migrations.CreateModel(
            name='ContactResponse',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('message', models.TextField(verbose_name='Response')),
                ('parent', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='contact_response', to='stela_control.contact')),
            ],
        ),
        migrations.CreateModel(
            name='Comments',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=150, verbose_name='Name')),
                ('email', models.EmailField(max_length=254, verbose_name='Email')),
                ('status', models.CharField(choices=[('Draft', 'Draft'), ('Published', 'Published')], default='Draft', max_length=10)),
                ('lang', models.CharField(max_length=80)),
                ('message', models.TextField(verbose_name='Message')),
                ('post', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='comments', to='stela_control.content')),
            ],
        ),
        migrations.CreateModel(
            name='ClubPoints',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('points', models.IntegerField()),
                ('order', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='stela_control.order')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='ChatSupport',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('response', models.TextField(verbose_name='Answer')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('case', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='stela_control.support')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='chat_response', to=settings.AUTH_USER_MODEL, verbose_name='Usuario')),
            ],
        ),
        migrations.CreateModel(
            name='Bulletpoints',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.CharField(blank=True, max_length=250, verbose_name='Bulletpoint')),
                ('product', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='stela_control.inventory')),
            ],
        ),
        migrations.CreateModel(
            name='BudgetControl',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('control_id', models.CharField(max_length=20)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('recipt', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='budget_control', to='stela_control.billingrecipt')),
            ],
        ),
        migrations.CreateModel(
            name='Budget',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('withdraw', models.BooleanField(default=False)),
                ('amount', models.DecimalField(decimal_places=2, max_digits=7)),
                ('date', models.DateTimeField(auto_now_add=True)),
                ('order', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='stela_control.order')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='Booking',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date', models.DateField()),
                ('dateConfirm', models.BooleanField(default=False)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.AddField(
            model_name='billingrecipt',
            name='customer',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='customer', to='stela_control.customer'),
        ),
        migrations.AddField(
            model_name='billingrecipt',
            name='owner',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='owner', to=settings.AUTH_USER_MODEL),
        ),
        migrations.CreateModel(
            name='Addresses',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(default='Not Selected', max_length=50)),
                ('address', models.CharField(help_text='Required', max_length=255, verbose_name='Address Line')),
                ('phone', models.CharField(max_length=14, null=True)),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('city_address', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='geolocation.city')),
                ('country_address', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='geolocation.country', verbose_name='Country')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ('-created',),
            },
        ),
        migrations.CreateModel(
            name='ProStelaExpert',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('model', models.CharField(max_length=80)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('owner', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='owner_proexpert', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'unique_together': {('owner', 'model')},
            },
        ),
    ]



from decimal import Decimal
from unittest import result
from urllib import response
from django.http import JsonResponse, HttpResponse, HttpResponseRedirect, Http404
import json
from django.core.files import File
import os
from django.utils.translation import gettext_lazy as _
from paypalcheckoutsdk.orders import OrdersGetRequest
from django.urls import reverse
from django.shortcuts import render, redirect, get_object_or_404
from django.contrib import messages
import stripe
from django.contrib.auth.decorators import login_required
from django.views.decorators.csrf import csrf_exempt
from accounts.models import UserBase
from django.utils import translation
from linkzone.context_processors import cart
from stela_control.models import Budget, StelaPayments
from linkzone.cart import Cart
from stela_control.models import (
    Content, Order, StelaSelection, 
    StelaItems, ControlFacturacion, FacturaItems, StelaPayments, 
    PathControl, BillingRecipt, TemplateSections,
    DataEmail, DynamicBullets, OrderItems, ItemServices, Modules, Support, 
    ChatSupport, SupportResponse, SitePolicy, Customer, Comments, PetData,
    Inventory, Contact, Booking, YouTubeToken, Club, Discussion, Message,
    Resource, LiteraryWork
    )
from stela_control.models import DataEmail, Content, Team
from stela_control.forms import ContactForm, DataEmailForm, NewsletterForm, ResourceForm, BillFileForm
from django.core.mail import EmailMultiAlternatives
import datetime 
from django.contrib.sites.shortcuts import get_current_site
from django.utils.html import strip_tags
from django.conf import settings
from django.utils.crypto import get_random_string
from django.template.loader import render_to_string
from django.core.mail import EmailMultiAlternatives
from django import template
from stela_control.views import get_youtube_playlist_videos
from googleapiclient.discovery import build
from googleapiclient.errors import HttpError

# Create your views here.
register = template.Library()
@register.filter(name='cash', is_safe=False)
def cash(val, precision=2):
    try:
        int_val = int(val)
    except ValueError:
        raise template.TemplateSyntaxError(
        f'Value must be an integer. {val} is not an integer')

    if int_val < 1000:
        return str(int_val)
    elif int_val < 1_000_000:
        return f'{int_val/1000.0:.{precision}f}'.rstrip('0').rstrip('.') + 'K'
    else:
        return f'{int_val/1_000_000.0:.{precision}f}'.rstrip('0').rstrip('.') + 'M'

def home(request):
    lang=request.LANGUAGE_CODE
    author=UserBase.objects.get(is_superuser=True)
    about=Content.objects.filter(author=author, section="About Values", lang=lang)
    apps=Content.objects.filter(author=author, path="Services", lang=lang)
    cards=Content.objects.filter(author=author, section="Card Content", lang=lang)
    image_bullets=Content.objects.filter(author=author,section="Image Bullet", lang=lang)
    box_bullet=Content.objects.filter(author=author, section="Icon Box", lang=lang)
    context = {
        'about': about,
        'apps': apps,
        'cards': cards,
        'image_bullet': image_bullets,
        'box_bullets': box_bullet,
    }

    return render(request, 'home/index.html', context)

@login_required
def product_detail(request, slug):
    comments = Comments.objects.filter(status=True, product__slug=slug).order_by('-created_at')
    user = request.user 
    pets = PetData.objects.filter(owner=user.id)
    service = Inventory.objects.get(slug=slug)
    form = DataEmailForm()
    
    if request.method == 'POST':
            form = DataEmailForm(request.POST)
            if form.is_valid():
                email = form.cleaned_data['email']
                if DataEmail.objects.filter(email=email).exists():
                    form.save(commit=False)
                    return redirect('site:home')
                    
                else:
                    form.save()
                    messages.success(request, "successful subscription, thank you")
                    return HttpResponseRedirect(reverse('siteapp:home'))

    context ={
        'comments': comments,
        'pets':pets,
        'pricing': pricing,
        'service': service,
        'form': form
          }
    
    return render(request, 'siteapp/sections/costumer/product_detail.html', context)

def gallery(request):
    # galleries = Gallery.objects.filter(status="Published")
    form = DataEmailForm()
    
    if request.method == 'POST':
            form = DataEmailForm(request.POST)
            if form.is_valid():
                email = form.cleaned_data['email']
                if DataEmail.objects.filter(email=email).exists():
                    form.save(commit=False)
                    return redirect('siteapp:home')
                    
                else:
                    form.save()
                    messages.success(request, "successful subscription, thank you")
                    return HttpResponseRedirect(reverse('siteapp:home'))

    context ={
        # 'galleries': galleries,
        'form': form,
    }
    return render(request, 'siteapp/sections/media/gallery.html', context)

def userGallery(request, id):
    # galleries = Gallery.objects.filter(status="Published")
    # get_gallery = Gallery.objects.get(id=id)
    # collage = ImageGallery.objects.filter(parent_id=id)
    form = DataEmailForm()
    
    if request.method == 'POST':
            form = DataEmailForm(request.POST)
            if form.is_valid():
                email = form.cleaned_data['email']
                if DataEmail.objects.filter(email=email).exists():
                    form.save(commit=False)
                    return redirect('siteapp:home')
                    
                else:
                    form.save()
                    messages.success(request, "successful subscription, thank you")
                    return HttpResponseRedirect(reverse('siteapp:home'))
    context ={
        # 'galleries': galleries,
        # 'get_gallery': collage,
        'form': form
    }
    return render(request, 'siteapp/sections/gallery.html', context)

def blog_detail(request, slug):
    user = request.user
    user_id = user.id
    admin = UserBase.objects.get(id=user_id, is_staff=True)
    # blog = News.objects.get(status='Publish', slug=slug)
    # commentform = CommentForm()
    # comments = Comments.objects.filter(post_id=blog.id, status='Published')
    form = DataEmailForm()
    
    if request.method == 'POST':
            form = DataEmailForm(request.POST)
            if form.is_valid():
                email = form.cleaned_data['email']
                if DataEmail.objects.filter(email=email).exists():
                    form.save(commit=False)
                    return redirect('siteapp:home')
                    
                else:
                    form.save()
                    messages.success(request, "successful subscription, thank you")
                    return HttpResponseRedirect(reverse('siteapp:home'))
    

    context = {
      'admin': admin,
    #   'blog': blog,
    #   'commentsform': commentform,
    #   'comments': comments,
      'form': form
    }
    if request.method == 'POST':  
        # form = CommentForm(request.POST)
        if form.is_valid():
           comment = form.save(commit=False)
        #    comment.post = blog
           comment.save()

           messages.success(request, "Your review was send in minutes will be published")
        #    return HttpResponseRedirect(reverse('siteapp:blog_detail', args=[blog.slug]))

    return render(request, 'siteapp/sections/media/single-blog.html', context)

def pricing(request):
    lang=request.LANGUAGE_CODE
    owner = request.user.is_superuser
    services = Inventory.objects.filter(owner=owner, status="Active", lang=lang)
    context = {
      'services': services
    }
    
    return render(request, 'siteapp/sections/costumer/pricing.html', context)

def new_message(request):
    form = ContactForm()
    newsletter = DataEmailForm()
    context = {
      'form': form,
      'newsletter':newsletter
    }
    
    if request.method == 'POST':
       form = ContactForm(request.POST)
       if form.is_valid():
          form.save()
          user_email = form.cleaned_data['email']
          subject = form.cleaned_data['subject']
          full_name = form.cleaned_data['name']
          current_site = get_current_site(request)
          html_content = render_to_string('emails/transactionals/message_recieve.html', {
                            'name': full_name,
                            'domain': current_site.domain,
                            })
          text_content = strip_tags(html_content)

          email = EmailMultiAlternatives(
               'We have received your message',
               text_content,
               settings.DEFAULT_EMAIL,
               [user_email]
           
           )
          email.attach_alternative(html_content, "text/html")
          email.send()
          
          user = request.user
          html_content = render_to_string('stela_control/emails-template/message_notification.html', {
                            'name': full_name,
                            'email': user_email,
                            'subject': subject,
                            'created': datetime.datetime.now()
                            })
          text_content = strip_tags(html_content)

          email = EmailMultiAlternatives(
               'They have sent you a message',
               text_content,
               settings.STELA_EMAIL,
               [settings.DEFAULT_EMAIL]
           
           )
          email.attach_alternative(html_content, "text/html")
          email.send()

          if Contact.objects.filter(email=user_email,newsletter=True):

             if DataEmail.objects.filter(email=user_email).exists():
                pass
             else:
                DataEmail.objects.create (
                         email=user_email,
                )

          messages.success(request, "Your message has been sent")
          return HttpResponseRedirect(reverse('siteapp:contact'))

    return render(request, 'siteapp/sections/media/contact.html', context)

def cart_add(request):
    cart = Cart(request)
    if request.POST.get('action') == 'post':
        price = str(request.POST.get('price'))
        serviceid = str(request.POST.get('service'))
        catalog=Inventory.objects.get(pk=serviceid)
        selection = StelaSelection.objects.filter(
            integration=catalog,
            status="Pending"
            )

        if selection.exists():
            selection.delete()
            
        get_select=StelaSelection.objects.create(
            integration=catalog,
            amount=price
            )
        cart.service_add(selectid=get_select.pk)
        cart_count = cart.__len__()
        response = JsonResponse({'count':cart_count})
        return response

def reorder(request):
    cart = Cart(request)
    if request.POST.get('action') == 'post':
        orderid = str(request.POST.get('orderid'))
        orderitems = OrderItems.objects.filter(order_id=orderid)
        for order in orderitems:
            select = StelaSelection.objects.get(
                pk=order.stela_selection.pk, 
                status="Payeed"
            )
            cart.service_add(selectid=select.id)

        cart_count = cart.__len__()
        response = JsonResponse({'count':cart_count})
        return response
    
def query(request):
    form = DataEmailForm()
    if request.method == 'POST':
            form = DataEmailForm(request.POST)
            if form.is_valid():
                email = form.cleaned_data['email']
                if DataEmail.objects.filter(email=email).exists():
                    form.save(commit=False)
                    return redirect('site:home')
                    
                else:
                    form.save()
                    messages.success(request, "successful subscription, thank you")
                    return HttpResponseRedirect(reverse('siteapp:home'))

    if request.POST.get('answer') == 'registered user':
       response = JsonResponse({'member': 'Return Something'})
       return response

    if request.POST.get('answer') == 'new user':
       response = JsonResponse({'newcomer': 'Return Something'})
       return response
        
    return render(request, 'siteapp/sections/costumer/site-query.html', {'form':form})

def checkout(request):
    
    return render(request, 'siteapp/sections/checkout/cart.html')

def getDate(request):
    cart = Cart(request)
    user=request.user
    if request.POST.get('action') == 'post':
        date = (request.POST.get('date'))
        get_date = Booking.objects.filter(user_id=user.id, date=date, dateConfirm=False)
        
        if get_date.exists():
            get_date.delete()

        if not date:
            response = JsonResponse({'empty': 'Please select a date.'})
            return response

        dateConfirmed = Booking.objects.filter(date=date, dateConfirm=True).count()

        if dateConfirmed == 10:
            response = JsonResponse({'booked': 'Dates booked, please select another one.'})
            return response
        else:
            Booking.objects.create(
                date=date,
                user=user
            )
            cart.date_add(userid=user.id)
            response = JsonResponse({'success': 'The selected date is available.'})
            return response

def changeDate(request):
    
    if request.POST.get('action') == 'post':
        order_id = (request.POST.get('orderid'))
        date = (request.POST.get('date'))
        print(order_id)
        order = Order.objects.filter(id=order_id)
        if not date:
            response = JsonResponse({'empty': 'Please select a date.'})
            return response

        dateConfirmed = Booking.objects.filter(date=date, dateConfirm=True).count()

        if dateConfirmed == 10:
            response = JsonResponse({'booked': 'Dates booked, please select another one.'})
            return response
        else:
            order.update(appointment_date=date)
            response = JsonResponse({'success': 'The selected date is available.'})
            return response

def order_placed(request):
    user = request.user
    order = Order.objects.filter(user_id=user.id).latest('id')
    context = {
        'order': order
    }
    return render(request, 'siteapp/sections/checkout/order_placed.html', context)

def aboutUs(request):
    policies = SitePolicy.objects.filter(status="Publish", policy="About us")
    context = {
        'policies': policies
    }
    return render(request, 'siteapp/sections/docs/about.html', context)

def terms(request):
    policies = SitePolicy.objects.filter(status="Publish")
    context = {
        'policies': policies
    }
    return render(request, 'siteapp/sections/docs/terms.html', context)

def newsletter(request):
    if request.method == 'POST':
        form = NewsletterForm(request.POST)
        if form.is_valid():
            email = form.cleaned_data['email']
            if DataEmail.objects.filter(email=email).exists():
                response = JsonResponse({'success': 'Este email esta registrado.'})         
            else:
                form.save()
                response = JsonResponse({'success': 'Registro exitoso, gracias.'})
        else:
            print(form.errors)
            response = JsonResponse({'alert': 'Proceso fallido, por favor, ingrese un correo electrónico válido.'})
    return response

#virtualLibrary
def virtualLibraryHome(request):
    
    context = {
        
    }
    return render(request, 'siteapp/sections/docs/about.html', context)

def getBestSellers(self, *args, **kwargs):
    service = build('books', 'v1', developerKey=settings.GCP_API_KEY)
    query = 'bestsellers'  # Puedes modificar la consulta segun tu preferencia
    response = service.volumes().list(q=query, maxResults=10).execute()

    for item in response.get('items', []):
        book, created = LiteraryWork.objects.get_or_create(
            title=item['volumeInfo']['title'],
            authors=",".join(item['volumeInfo'].get('authors', '')),
            description=item['volumeInfo'].get('description', ''),
            thumbnail_url=item['volumeInfo'].get('imageLinks', {}).get('thumbnail', ''),
            info_link=item['volumeInfo'].get('infoLink', ''),
        )

        if created:
            self.stdout.write(self.style.SUCCESS(f'Added book: {book.title}'))

def search_books(request):
    context = {}

    if 'query' in request.GET:
        query = request.GET['query']
        service = build('books', 'v1', developerKey=settings.GCP_API_KEY)
        books = service.volumes().list(q=query).execute()

        context['books'] = books.get('items', [])

    return render(request, 'search_books.html', context)

#readClub
def create_club(request):
    if request.method == 'POST':
        name = request.POST.get('name')
        description = request.POST.get('description')
        club = Club.objects.create(name=name, description=description)
        # Suponiendo que quieres que el creador se una automáticamente al club
        club.members.add(request.user)
        return redirect('detalle_club', club_id=club.id)

def create_discussion(request, club_id):
    if request.method == 'POST':
        topic = request.POST.get('topic')
        club = Club.objects.get(id=club_id)
        discussion = Discussion.objects.create(
            club=club,
            topic=topic,
            starter=request.user
        )
        return redirect('detalle_discusion', discussion_id=discussion.id)
    
def join_club(user, club_id):
    # Agregar un usuario a la lista de miembros de un club de lectura.
    pass

def add_book_to_club(club_id, book_title, author, summary):
    # Agregar un libro al club de lectura.
    pass

def post_discussion(user, club_id, content):
    # Publicar una nueva discusión en un club de lectura.
    pass

def send_update_to_members(club_id, message):
    # Enviar una actualización a todos los miembros del club de lectura.
    pass

def leave_club(user, club_id):
    # Remover un usuario de la lista de miembros de un club de lectura.
    pass

def close_discussion(request, discussion_id):
    discussion = Discussion.objects.get(id=discussion_id)
    # Agregar lógica para verificar si el usuario puede cerrar la discusión
    discussion.is_closed = True
    discussion.save()
    return redirect('detalle_discusion', discussion_id=discussion.id)

#resources
def download_resource(request, resource_id):
    resource = get_object_or_404(Resource, id=resource_id)
    file_path = resource.file.path
    if os.path.exists(file_path):
        with open(file_path, 'rb') as fh:
            response = HttpResponse(fh.read(), content_type="application/vnd.ms-excel")
            response['Content-Disposition'] = 'inline; filename=' + os.path.basename(file_path)
            return response
    raise Http404

def calcular_islr(amount, tasa_islr=0.34):
   
    islr = amount * tasa_islr if tasa_islr else 0
    
    return {
        'ISLR': islr,
    }

def calcular_igtf(amount, tasa_igtf=0.02):

    igtf = amount * tasa_igtf if tasa_igtf else 0

    return {
        'IGTF': igtf
    }

def calcular_iva(amount, tasa_iva=0.16):

    iva = amount * tasa_iva if tasa_iva else 0

    return {
        'IVA': iva,
    }

def upload_billFile(request):
    if request.method == 'POST':
        form = BillFileForm(request.POST, request.FILES)
        if form.is_valid():
            factura = form.save(commit=False)
            factura.cliente = request.user
            factura.save()
            # Redireccionar a alguna vista de confirmación o al listado de facturas
            return redirect('facturas')
    else:
        form = BillFileForm()
    return render(request, 'upload_factura.html', {'form': form})


from setuptools import setup, find_packages

setup(
    name='stela_control_dynamic',
    version='1.3.2',
    packages=find_packages(exclude=['core', 'core.*']),
    include_package_data=True,
    license='MIT',
    description='All apps in one for business.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    install_requires=[
        'aiohttp==3.8.3',
        'aiosignal==1.3.1',
        'annotated-types==0.6.0',
        'anyio==3.7.1',
        'asgiref==3.7.0',
        'asn1crypto==1.5.1',
        'async-timeout==4.0.2',
        'attrs==22.2.0',
        'Babel==2.12.1',
        'beautifulsoup4==4.12.2',
        'bleach==6.0.0',
        'boto3==1.24.36',
        'botocore==1.27.36',
        'cachetools==5.3.1',
        'certifi==2021.10.8',
        'cffi==1.15.1',
        'charset-normalizer==2.0.12',
        'click==8.1.3',
        'colorama==0.4.5',
        'cryptography==38.0.3',
        'cssselect2==0.6.0',
        'curlify==2.2.1',
        'distro==1.8.0',
        'Django==5.0',
        'django-admin-thumbnails==0.2.6',
        'django-autoslug==1.9.8',
        'django-cities-light==3.9.2',
        'django-compat==1.0.15',
        'django-crispy-forms==1.14.0',
        'django-cron==0.6.0',
        'django-csp==3.7',
        'django-environ==0.7.0',
        'django-hosts==5.1',
        'django-htmx==1.12.0',
        'django-js-asset==2.0.0',
        'django-mailjet==0.3.1',
        'django-model-utils==4.3.1',
        'django-mptt==0.13.4',
        'django-phonenumber-field==7.1.0',
        'django-sass-processor==1.2.2',
        'django-storages==1.12.3',
        'exceptiongroup==1.1.3',
        'facebook-business==17.0.0',
        'frozenlist==1.3.3',
        'future==0.18.2',
        'google-api-core==2.11.0',
        'google-auth==2.19.1',
        'google-cloud-monitoring==2.15.0',
        'googleapis-common-protos==1.59.0',
        'grpcio==1.54.2',
        'grpcio-status==1.54.2',
        'gunicorn==20.1.0',
        'h11==0.14.0',
        'html5lib==1.1',
        'httpcore==1.0.1',
        'httpx==0.25.1',
        'idna==3.3',
        'jmespath==1.0.1',
        'lxml==4.9.1',
        'mailjet-rest==1.3.4',
        'MarkupSafe==2.1.2',
        'multidict==6.0.4',
        'openai==1.2.2',
        'oscrypto==1.3.0',
        'paypal-checkout-serversdk==1.0.1',
        'paypalhttp==1.0.1',
        'google-api-core==2.11.0',
        'google-api-python-client==2.108.0',
        'google-auth==2.19.1',
        'google-auth-httplib2==0.1.1',
        'google-auth-oauthlib==1.1.0',
        'google-cloud-monitoring==2.15.0',
        'googleapis-common-protos==1.59.0',
        'python-amazon-paapi==5.0.1',
        'paypalrestsdk==1.13.1',
        'phonenumbers==8.13.13',
        'Pillow==9.0.0',
        'progressbar2==4.0.0',
        'proto-plus==1.22.2',
        'protobuf==4.23.2',
        'pyasn1==0.5.0',
        'pyasn1-modules==0.3.0',
        'pycountry==22.3.5',
        'pycparser==2.21',
        'pycryptodome==3.14.1',
        'pydantic==2.4.2',
        'pydantic_core==2.10.1',
        'pyHanko==0.13.2',
        'pyhanko-certvalidator==0.19.5',
        'pyOpenSSL==22.1.0',
        'PyPDF3==1.0.6',
        'python-bidi==0.4.2',
        'python-dateutil==2.8.2',
        'python-utils==3.1.0',
        'pytz==2021.3',
        'pytz-deprecation-shim==0.1.0.post0',
        'PyYAML==6.0',
        'qrcode==7.3.1',
        'reportlab==3.6.11',
        'requests==2.27.1',
        'rsa==4.9',
        's3transfer==0.6.0',
        'six==1.16.0',
        'sniffio==1.3.0',
        'soupsieve==2.4.1',
        'sqlparse==0.4.2',
        'stripe==2.68.0',
        'svglib==1.4.1',
        'swapper==1.3.0',
        'tinycss2==1.1.1',
        'tqdm==4.64.0',
        'typing_extensions==4.8.0',
        'tzdata==2022.1',
        'tzlocal==4.2',
        'Unidecode==1.3.2',
        'uritools==4.0.0',
        'urllib3==1.26.9',
        'webencodings==0.5.1',
        'whois==0.9.13',
        'xhtml2pdf==0.2.8',
        'yarl==1.8.2',
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)